#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 stack
version:              2.9.3.1
visibility:           public
id:                   stack-2.9.3.1-KPxTFGy5pYG72g3kO1USDx
key:                  stack-2.9.3.1-KPxTFGy5pYG72g3kO1USDx
license:              BSD-3-Clause
maintainer:           manny@fpcomplete.com
author:               Commercial Haskell SIG
homepage:             http://haskellstack.org
synopsis:             The Haskell Tool Stack
description:
    Please see the documentation at <https://docs.haskellstack.org>
    for usage information.

    If building a '\''stack'\'' executable for distribution, please download the
    source code from <https://github.com/commercialhaskell/stack/releases>
    and build it using Stack itself in order to ensure identical behaviour
    to official binaries.  This package on Hackage is provided for convenience
    and bootstrapping purposes.

    Note that the API for the library is not currently stable, and may
    change significantly, even between minor releases. It is
    currently only intended for use by the executable.

category:             Development
abi:                  8384e7921583032769cd39cec4346580
exposed:              True
exposed-modules:
    Control.Concurrent.Execute Data.Attoparsec.Args
    Data.Attoparsec.Combinators Data.Attoparsec.Interpreter
    Data.Monoid.Map Network.HTTP.StackClient Options.Applicative.Args
    Options.Applicative.Builder.Extra Options.Applicative.Complicated
    Path.CheckInstall Path.Extra Path.Find Paths_stack Stack.Build
    Stack.Build.Cache Stack.Build.ConstructPlan Stack.Build.Execute
    Stack.Build.Haddock Stack.Build.Installed Stack.Build.Source
    Stack.Build.Target Stack.BuildPlan Stack.Clean Stack.Config
    Stack.Config.Build Stack.Config.Docker Stack.Config.Nix
    Stack.ConfigCmd Stack.Constants Stack.Constants.Config
    Stack.Coverage Stack.DefaultColorWhen Stack.Docker Stack.Dot
    Stack.FileWatch Stack.GhcPkg Stack.Ghci Stack.Ghci.Script
    Stack.Hoogle Stack.IDE Stack.Init Stack.List Stack.Lock Stack.Ls
    Stack.New Stack.Nix Stack.Options.BenchParser
    Stack.Options.BuildMonoidParser Stack.Options.BuildParser
    Stack.Options.CleanParser Stack.Options.Completion
    Stack.Options.ConfigParser Stack.Options.DockerParser
    Stack.Options.DotParser Stack.Options.ExecParser
    Stack.Options.GhcBuildParser Stack.Options.GhcVariantParser
    Stack.Options.GhciParser Stack.Options.GlobalParser
    Stack.Options.HaddockParser Stack.Options.HpcReportParser
    Stack.Options.LogLevelParser Stack.Options.NewParser
    Stack.Options.NixParser Stack.Options.PackageParser
    Stack.Options.ResolverParser Stack.Options.SDistParser
    Stack.Options.ScriptParser Stack.Options.TestParser
    Stack.Options.UploadParser Stack.Options.Utils Stack.Package
    Stack.PackageDump Stack.Path Stack.Prelude Stack.Runners
    Stack.SDist Stack.Script Stack.Setup Stack.Setup.Installed
    Stack.SetupCmd Stack.SourceMap Stack.Storage.Project
    Stack.Storage.User Stack.Storage.Util Stack.Types.Build
    Stack.Types.Compiler Stack.Types.CompilerBuild Stack.Types.Config
    Stack.Types.Config.Build Stack.Types.Docker Stack.Types.GhcPkgId
    Stack.Types.NamedComponent Stack.Types.Nix Stack.Types.Package
    Stack.Types.PackageName Stack.Types.Resolver Stack.Types.SourceMap
    Stack.Types.TemplateName Stack.Types.Version Stack.Unpack
    Stack.Upgrade Stack.Upload System.Info.ShortPathName
    System.Permissions System.Process.Pager System.Terminal

hidden-modules:
    Path.Extended Stack.ComponentFile Stack.PackageFile
    Stack.Types.Cache Stack.Types.Dependency Stack.Types.PackageFile
    Stack.Types.Storage System.Uname

import-dirs:          /usr/lib/ghc-9.6.6/site-local/stack-2.9.3.1
library-dirs:         /usr/lib/ghc-9.6.6/site-local/stack-2.9.3.1
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/stack-2.9.3.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/stack
hs-libraries:         HSstack-2.9.3.1-KPxTFGy5pYG72g3kO1USDx
depends:
    Cabal-3.10.3.0 aeson-2.2.1.0-AeqJOB7WzlfHEyTUHodGhY
    annotated-wl-pprint-0.7.0-GFWp72SduKx5Zv0YaM2sPQ
    ansi-terminal-1.1-CupeHe6p1cfEgQRMak7it6 array-0.5.6.0
    async-2.2.6-JFqXkyZWakA6MSvky6jlwB
    attoparsec-0.14.4-KXEn0UTGiviKHW1W4Txem1 base-4.18.2.1
    base64-bytestring-1.2.1.0-BWOGj3HDdwSDbLnS8UTB67
    bytestring-0.11.5.3 casa-client-0.0.3-39oVVUb0xWa4VAPTnABBBN
    casa-types-0.0.3-HyXwZg2zhi06RRJ4SGmggB
    colour-2.3.7-EKfA4aBVDkg4QWh8rS68yt
    conduit-1.3.6.1-ASxyqnNN5o6JNEZENxLkTo
    conduit-extra-1.3.8-4ND3rHkWnMCxT3MRqBhox containers-0.6.7
    crypton-1.0.4-9X1u0CSNxWEC7SbXf95SkB
    crypton-conduit-0.2.3-1y9i1ItJWKA38jsS2whPzi deepseq-1.4.8.1
    directory-1.3.8.5 echo-0.1.4-BCPf0iNIcqQJp7PonIPBEA
    exceptions-0.10.7 extra-1.7.16-GG4oQL1Pbvk2YReVs3ucdi
    file-embed-0.0.16.0-6A32wX7iXBC7ZTuLWlLLWz
    filelock-0.1.1.8-JNERZGdwDFFO39UkXgvBS filepath-1.4.300.1
    fsnotify-0.4.4.0-8n5j3QjK14ZBELO91TWNa
    generic-deriving-1.14.7-J1HN6h7IPom2Ro1vT5j8mf
    hackage-security-0.6.3.2-F9238iXb6SED4dBIEP9AxK
    hashable-1.4.7.0-8qGpYVybfmaKH8giGSMaAG
    hi-file-parser-0.1.8.0-4lDBs1S57SX7X6G1ithd3T
    hpack-0.38.0-6l4Mgumt8Gg9gSt1ZgSFtF hpc-0.6.2.0
    http-client-0.7.19-IEWR3rTgLbz23aQ2c2Laos
    http-client-tls-0.3.6.4-CMU3qOsy0CoKjjjUtTBlgx
    http-conduit-2.3.9.1-EXT0Jnfj3v0DhzxQQnnhUg
    http-download-0.2.1.0-9DPMw44MEKHLEYIEt1H3T8
    http-types-0.12.4-YzImfxD6FM4aZnfovaubB
    memory-0.18.0-6zo36PbRecTK4fqbBnx0f5
    microlens-0.4.14.0-IP2Uuhm3qTnDhkfYobH8B3
    mintty-0.1.4-CFeOovjDLzzJb68ZeM2nF
    mono-traversable-1.0.21.0-4AVokNrJdRrD6jNwgrzgJs mtl-2.3.1
    mustache-2.4.3.1-2HJjXNV1NSd8fXVUjpdAwo
    neat-interpolation-0.5.1.4-JYaYRVzVxsQIErjz9kX8JN
    network-uri-2.6.4.2-JVtNAVx4uuKIiYA1iZNoT1
    open-browser-0.2.1.1-LxNiN4VEneo8bxQiPfYDai
    optparse-applicative-0.18.1.0-64q3Zt8gfMnAm6zpFRaIVN
    pantry-0.8.3-G9sdjftpVSw1ytJbFX4Z2v
    path-0.9.6-I4rUWsdXmPLGcjRhlvxJ8F
    path-io-1.8.2-CCAuficxi9QFdJlJ52rZNC
    persistent-2.14.5.2-2JzkpZSkuF16uVA2fJmQDR
    persistent-sqlite-2.13.2.0-17QrIyHK9fK3WXBqqxdK5O pretty-1.1.3.6
    primitive-0.9.1.0-CTO5MxhiVrsFEEvGOrOd6k process-1.6.19.0
    project-template-0.2.1.0-L4QhvtJPLPl8LcBaelOPUp
    random-1.2.1.3-Fpl3dUa1VuLH6jaWIu29Ly
    retry-0.9.3.1-4Osb5lftJAdEYQ0wlmFj1R
    rio-0.1.24.0-EHdoxr650Hl5EbL4hqFb3V
    rio-prettyprint-0.1.8.0-HsyYCXYQlmN9X0K7RPZSbt
    split-0.2.5-EKe1ugt4PcK1OrhPFnT5ou stm-2.5.1.0
    streaming-commons-0.2.3.1-8T2JfTLc56G6WXWvSXEF4O
    tar-0.5.1.1-GuMrQ7H3fn233jOBbXLK84 template-haskell-2.20.0.0
    temporary-1.3-AzCvydY1Gof51L3aNIQbtm text-2.0.2
    text-metrics-0.3.3-GVsk3dI5KaaJh9Pj68j7yp
    th-reify-many-0.1.10-Aw82NGU3ynnGM9ABIE03I5 time-1.12.2
    tls-2.0.6-K7g7Oy3E5e3DsNiPnXBpiH transformers-0.6.1.0
    typed-process-0.2.13.0-3ZCfq5nw2Ul1uSCVtX6y3p
    unicode-transforms-0.4.0.1-AScKGlT29tQIsJEBhijADK unix-2.8.4.0
    unix-compat-0.7.4.1-BnGVCTqWzO94VHR7bIvixK
    unliftio-0.2.25.1-7sXhGHm93AhzYdedcIgQ6
    unordered-containers-0.2.20.1-9qHVoc2smYt9flJ6feRxGY
    vector-0.13.2.0-AWRowWUrdYO1choGzrrEgg
    yaml-0.11.11.2-3uuTzm3w0KboX5NWuQdx3
    zip-archive-0.4.3.2-EhNyMZypzRXL4lX0cio1Yh
    zlib-0.7.0.0-9tInHQLlnhqDdO053RkpzP

haddock-interfaces:   /usr/share/doc/stack/html/stack.haddock
haddock-html:         /usr/share/doc/stack/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

